cosmpy.protos.cosmos.params.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.params.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.params.v1beta1.params_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.params.v1beta1.params_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.params.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.params.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.params.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service.

  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.params.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service.

  Params(request, context)

    Params queries a specific parameter of a module, given its subspace and key.

class cosmpy.protos.cosmos.params.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service.

cosmpy.protos.cosmos.params.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## Module contents